@@ -7,7 +7,7 @@ from onto_tool import onto_tool
 def test_action_message(caplog):
     caplog.set_level(logging.INFO)
     onto_tool.main([
-        'bundle', 'tests/bundle/message.yaml'
+        'bundle', '-v', 'output', 'tests-output/bundle', 'tests/bundle/message.yaml'
     ])
 
     logs = caplog.text
