@@ -7,11 +7,12 @@ from rdflib.namespace import SKOS, RDF
 
 def test_transform_sparql():
     onto_tool.main([
-        'bundle', '-v', 'lang', 'en', 'tests/bundle/transform_sparql.yaml'
+        'bundle', '-v', 'output', 'tests-output/bundle',
+        '-v', 'lang', 'en', 'tests/bundle/transform_sparql.yaml'
     ])
 
     updated_graph = Graph()
-    updated_graph.parse('tests/bundle/transform_sparql_data_en.ttl', format='turtle')
+    updated_graph.parse('tests-output/bundle/transform_sparql_data_en.ttl', format='turtle')
     without_lang = [label for label in updated_graph.objects(None, SKOS.prefLabel)
                     if label.language != 'en']
     assert len(without_lang) == 0
@@ -19,11 +20,12 @@ def test_transform_sparql():
 
 def test_transform_java():
     onto_tool.main([
-        'bundle', '-v', 'format', 'rdf-xml', 'tests/bundle/transform_java.yaml'
+        'bundle', '-v', 'output', 'tests-output/bundle',
+        '-v', 'format', 'rdf-xml', 'tests/bundle/transform_java.yaml'
     ])
 
     updated_graph = Graph()
-    updated_graph.parse('tests/bundle/transform_sparql_data.xml', format='xml')
+    updated_graph.parse('tests-output/bundle/transform_sparql_data.xml', format='xml')
     types = list(updated_graph.subject_objects(RDF.type))
     assert len(types) == 2
 
@@ -31,7 +33,8 @@ def test_transform_java():
 def test_transform_shell(caplog):
     with caplog.at_level(logging.DEBUG):
         onto_tool.main([
-            'bundle', 'tests/bundle/transform_shell.yaml'
+            'bundle', '-v', 'output', 'tests-output/bundle',
+            'tests/bundle/transform_shell.yaml'
         ])
 
     output = caplog.messages
