@@ -1,5 +1,4 @@
 from onto_tool import onto_tool
-import glob
 import pydot
 
 
@@ -8,12 +7,12 @@ def test_local_instance():
         'graphic',
         '-t', 'Local Ontology',
         '--no-image',
-        '-o', 'tests/graphic/test_schema',
+        '-o', 'tests-output/graphic/test_schema',
         'tests/graphic/domain_ontology.ttl',
         'tests/graphic/upper_ontology.ttl',
         'tests/graphic/instance_data.ttl'
     ])
-    (instance_graph,) = pydot.graph_from_dot_file('tests/graphic/test_schema.dot')
+    (instance_graph,) = pydot.graph_from_dot_file('tests-output/graphic/test_schema.dot')
     edges = list(sorted((e.get_source(), e.get_destination()) for e in instance_graph.get_edges()))
     assert edges == [
         ('Domain', 'Upper'),
